@@ -22,9 +22,9 @@ STATUS_CHOICES = [
 
 
 class Circle(Model):
-    name = models.CharField(max_length=255, blank=True, default='')
-    subtitle = models.CharField(max_length=255, blank=True, default='')
-    description = models.TextField(blank=True, default='')
+    name = models.CharField(max_length=255, blank=True, null=True, default='')
+    subtitle = models.CharField(max_length=255, blank=True, null=True, default='')
+    description = models.TextField(blank=True, null=True, default='')
     creationDate = models.DateField(auto_now_add=True)
     status = models.CharField(max_length=8, choices=STATUS_CHOICES, default='Public')
     owner = models.ForeignKey(settings.AUTH_USER_MODEL, related_name="owned_circles", on_delete=models.SET_NULL,
