@@ -9,11 +9,11 @@ from djangoldp.tests.settings_default import yaml_config
 # override config loading
 config = {
     # add the packages to the reference list
-    'ldppackages': ['djangoldp_circle', 'djangoldp_circle.tests'],
+    'ldppackages': ['djangoldp_account', 'djangoldp_circle', 'djangoldp_circle.tests'],
 
     # required values for server
     'server': {
-        'AUTH_USER_MODEL': 'tests.User',
+        'AUTH_USER_MODEL': 'djangoldp_account.LDPUser',
         'REST_FRAMEWORK': {
             'DEFAULT_PAGINATION_CLASS': 'djangoldp.pagination.LDPPagination',
             'PAGE_SIZE': 5
@@ -43,6 +43,7 @@ failures = test_runner.run_tests([
     'djangoldp_circle.tests.tests_save',
     'djangoldp_circle.tests.tests_view',
     'djangoldp_circle.tests.tests_post',
+    'djangoldp_circle.tests.tests_cache',
 ])
 if failures:
     sys.exit(failures)
