@@ -9,7 +9,7 @@ from rest_framework.test import APITestCase, APIClient
 from guardian.shortcuts import assign_perm
 
 from djangoldp_circle.models import Circle, CircleMember
-from djangoldp_circle.tests.models import User
+from djangoldp_circle.tests.utils import get_random_user
 
 
 class PermissionsTestCase(APITestCase):
@@ -17,12 +17,9 @@ class PermissionsTestCase(APITestCase):
         self.client = APIClient()
         LDListMixin.to_representation_cache.reset()
         LDPSerializer.to_representation_cache.reset()
-        LDPPermissions.invalidate_cache()
 
     def setUpLoggedInUser(self):
-        self.user = User(email='test@mactest.co.uk', first_name='Test', last_name='Mactest', username='test',
-                         password='glass onion')
-        self.user.save()
+        self.user = get_random_user()
         self.client.force_authenticate(user=self.user)
 
     def _get_random_circle(self, status_choice='Public', owner=None):
@@ -74,20 +71,17 @@ class PermissionsTestCase(APITestCase):
 
         return res
 
-    def _get_random_user(self):
-        return User.objects.create(email='{}@test.co.uk'.format(str(uuid.uuid4())), first_name='Test', last_name='Test',
-                                   username=str(uuid.uuid4()))
-
     # list circles - not logged in
     def test_list_circles_anonymous_user(self):
-        another_user = self._get_random_user()
+        another_user = get_random_user()
         self.setUpCircle('Public', another_user)
         response = self.client.get('/circles/')
-        self.assertEqual(response.status_code, 403)
+        self.assertEqual(response.status_code, 200)
+        self.assertEqual(len(response.data['ldp:contains']), 1)
 
     # GET circle - not logged in
     def test_get_circle_anonymous_user(self):
-        another_user = self._get_random_user()
+        another_user = get_random_user()
         self.setUpCircle('Public', another_user)
 
         response = self.client.get('/circles/1/')
@@ -97,7 +91,7 @@ class PermissionsTestCase(APITestCase):
     def test_list_circles(self):
         self.setUpLoggedInUser()
         # a public circle, a private circle I own and a private circle I'm not in
-        another_user = self._get_random_user()
+        another_user = get_random_user()
         public_circle = self._get_random_circle('Public', another_user)
         my_circle = self._get_random_circle('Private', self.user)
         private_circle = self._get_random_circle('Private', another_user)
@@ -109,7 +103,7 @@ class PermissionsTestCase(APITestCase):
     # GET circle public
     def test_get_public_circle(self):
         self.setUpLoggedInUser()
-        another_user = self._get_random_user()
+        another_user = get_random_user()
         self.setUpCircle('Public', another_user)
 
         response = self.client.get('/circles/1/')
@@ -126,12 +120,12 @@ class PermissionsTestCase(APITestCase):
     # GET circle private - I am not a member
     def test_get_circle_private_not_member(self):
         self.setUpLoggedInUser()
-        another_user = self._get_random_user()
+        another_user = get_random_user()
 
         self.setUpCircle('Private', another_user)
 
         response = self.client.get('/circles/1/')
-        self.assertEqual(response.status_code, 403)
+        self.assertEqual(response.status_code, 404)
 
     # POST a new circle - anyone authenticated can do this
     def test_post_circle(self):
@@ -148,7 +142,7 @@ class PermissionsTestCase(APITestCase):
     # PATCH circle public - denied
     def test_patch_public_circle(self):
         self.setUpLoggedInUser()
-        another_user = self._get_random_user()
+        another_user = get_random_user()
 
         self.setUpCircle('Public', another_user)
 
@@ -158,7 +152,7 @@ class PermissionsTestCase(APITestCase):
     # PATCH circle - I am a member but not an admin - denied
     def test_patch_circle_not_admin(self):
         self.setUpLoggedInUser()
-        another_user = self._get_random_user()
+        another_user = get_random_user()
 
         self.setUpCircle('Public', another_user)
         CircleMember.objects.create(circle=self.circle, user=self.user, is_admin=False)
@@ -169,7 +163,7 @@ class PermissionsTestCase(APITestCase):
     # PATCH circle - I am an admin
     def test_patch_circle_admin(self):
         self.setUpLoggedInUser()
-        another_user = self._get_random_user()
+        another_user = get_random_user()
 
         self.setUpCircle('Private', another_user)
         CircleMember.objects.create(circle=self.circle, user=self.user, is_admin=True)
@@ -180,7 +174,7 @@ class PermissionsTestCase(APITestCase):
     # adding a CircleMember - I am not a member myself
     def test_post_circle_member_not_member(self):
         self.setUpLoggedInUser()
-        another_user = self._get_random_user()
+        another_user = get_random_user()
 
         self.setUpCircle('Private', another_user)
 
@@ -191,7 +185,7 @@ class PermissionsTestCase(APITestCase):
 
     def test_post_circle_member_nested_not_member(self):
         self.setUpLoggedInUser()
-        another_user = self._get_random_user()
+        another_user = get_random_user()
 
         self.setUpCircle('Private', another_user)
 
@@ -209,7 +203,7 @@ class PermissionsTestCase(APITestCase):
     # adding a CircleMember - I am a member but not an admin
     def test_post_circle_member(self):
         self.setUpLoggedInUser()
-        another_user = self._get_random_user()
+        another_user = get_random_user()
 
         self.setUpCircle('Private', another_user)
         CircleMember.objects.create(circle=self.circle, user=self.user, is_admin=False)
@@ -222,7 +216,7 @@ class PermissionsTestCase(APITestCase):
     # removing a CircleMember - I am not an admin
     def test_delete_circle_member(self):
         self.setUpLoggedInUser()
-        another_user = self._get_random_user()
+        another_user = get_random_user()
 
         self.setUpCircle('Private', another_user)
         CircleMember.objects.create(circle=self.circle, user=self.user, is_admin=False)
@@ -232,7 +226,7 @@ class PermissionsTestCase(APITestCase):
 
     # removing a circle member - I am not logged in
     def test_delete_circle_member_anonymous_user(self):
-        another_user = self._get_random_user()
+        another_user = get_random_user()
         self.setUpCircle('Private', another_user)
 
         response = self.client.delete('/circle-members/1/')
@@ -241,7 +235,7 @@ class PermissionsTestCase(APITestCase):
     # removing myself from CircleMember - I am not an admin
     def test_delete_myself_circle_member(self):
         self.setUpLoggedInUser()
-        another_user = self._get_random_user()
+        another_user = get_random_user()
 
         self.setUpCircle('Private', another_user)
         CircleMember.objects.create(circle=self.circle, user=self.user, is_admin=False)
@@ -254,7 +248,7 @@ class PermissionsTestCase(APITestCase):
         self.setUpLoggedInUser()
         self.setUpCircle('Private', self.user)
 
-        another_user = self._get_random_user()
+        another_user = get_random_user()
 
         body = self._get_circle_member_request_json(another_user, self.circle)
 
@@ -269,7 +263,7 @@ class PermissionsTestCase(APITestCase):
         self.setUpLoggedInUser()
         self.setUpCircle('Private', self.user)
 
-        another_user = self._get_random_user()
+        another_user = get_random_user()
         body = self._get_circle_member_request_json(another_user)
 
         response = self.client.post('/circles/1/members/', data=json.dumps(body),
@@ -278,10 +272,10 @@ class PermissionsTestCase(APITestCase):
         circle = Circle.objects.get(pk=self.circle.pk)
         self.assertEqual(len(circle.members.all()), 2)
 
-        another_user = self._get_random_user()
+        another_user = get_random_user()
         body = self._get_circle_member_request_json(another_user, self.circle)
 
-        response = self.client.post('/users/{}/circles/'.format(another_user.pk), data=json.dumps(body),
+        response = self.client.post('/users/{}/circles/'.format(another_user.username), data=json.dumps(body),
                                     content_type='application/ld+json')
         self.assertEqual(response.status_code, 201)
         circle = Circle.objects.get(pk=self.circle.pk)
@@ -291,7 +285,7 @@ class PermissionsTestCase(APITestCase):
         self.setUpLoggedInUser()
         self.setUpCircle('Private', self.user)
 
-        another_user = self._get_random_user()
+        another_user = get_random_user()
         body = self._get_circle_member_request_json(another_user)
         response = self.client.post('/users/{}/members/'.format(another_user.pk), data=json.dumps(body),
                                     content_type='application/ld+json')
@@ -302,7 +296,7 @@ class PermissionsTestCase(APITestCase):
         self.setUpLoggedInUser()
         self.setUpCircle('Private', self.user)
 
-        another_user = self._get_random_user()
+        another_user = get_random_user()
         CircleMember.objects.create(circle=self.circle, user=another_user, is_admin=False)
 
         response = self.client.delete('/circle-members/2/')
@@ -313,7 +307,7 @@ class PermissionsTestCase(APITestCase):
         self.setUpLoggedInUser()
         self.setUpCircle('Private')
 
-        another_user = self._get_random_user()
+        another_user = get_random_user()
         CircleMember.objects.create(circle=self.circle, user=another_user, is_admin=True)
 
         response = self.client.delete('/circle-members/2/')
@@ -324,7 +318,7 @@ class PermissionsTestCase(APITestCase):
         self.setUpLoggedInUser()
         self.setUpCircle('Private')
 
-        another_user = self._get_random_user()
+        another_user = get_random_user()
         CircleMember.objects.create(circle=self.circle, user=another_user, is_admin=False)
 
         response = self.client.delete('/circle-members/1/')
@@ -335,7 +329,7 @@ class PermissionsTestCase(APITestCase):
         self.setUpLoggedInUser()
         self.setUpCircle('Private')
 
-        another_user = self._get_random_user()
+        another_user = get_random_user()
         CircleMember.objects.create(circle=self.circle, user=another_user, is_admin=True)
 
         self.assertEqual(self.circle.members.count(), 2)
@@ -348,7 +342,7 @@ class PermissionsTestCase(APITestCase):
     # PATCH circle-member - I am not an admin
     def test_patch_circle_member_not_admin(self):
         self.setUpLoggedInUser()
-        another_user = self._get_random_user()
+        another_user = get_random_user()
 
         self.setUpCircle('Private', another_user)
         CircleMember.objects.create(circle=self.circle, user=self.user, is_admin=False)
@@ -361,7 +355,7 @@ class PermissionsTestCase(APITestCase):
         self.setUpLoggedInUser()
         self.setUpCircle('Private', self.user)
 
-        another_user = self._get_random_user()
+        another_user = get_random_user()
         CircleMember.objects.create(circle=self.circle, user=another_user, is_admin=False)
 
         body = self._get_request_json(is_admin=True)
@@ -376,7 +370,7 @@ class PermissionsTestCase(APITestCase):
     # test that django guardian object-level permission is applied
     def test_guardian_view_applied(self):
         self.setUpLoggedInUser()
-        another_user = self._get_random_user()
+        another_user = get_random_user()
         self.setUpCircle('Private', another_user)
 
         assign_perm('view_circle', self.user, self.circle)
@@ -388,7 +382,7 @@ class PermissionsTestCase(APITestCase):
     # even with object-permission, I can't remove an admin
     def test_delete_circle_admin_guardian(self):
         self.setUpLoggedInUser()
-        another_user = self._get_random_user()
+        another_user = get_random_user()
         self.setUpCircle('Private', another_user)
 
         assign_perm('delete_circle', self.user, self.circle)
@@ -396,14 +390,14 @@ class PermissionsTestCase(APITestCase):
 
         response = self.client.delete('/circle-members/2/')
 
-        self.assertEqual(response.status_code, 403)
+        self.assertEqual(response.status_code, 404)
 
     # security test - admin changing which circle they are an admin of
     def test_hack_myself_admin_of_another_circle(self):
         self.setUpLoggedInUser()
         self.setUpCircle('Private', self.user)
 
-        another_user = self._get_random_user()
+        another_user = get_random_user()
         circle = Circle.objects.create(name='Test 2', status='Private', owner=another_user)
 
         payload = self._get_request_json(circle=circle.urlid)
@@ -418,10 +412,10 @@ class PermissionsTestCase(APITestCase):
         self.setUpLoggedInUser()
         self.setUpCircle('Private', self.user)
 
-        my_accomplice = self._get_random_user()
+        my_accomplice = get_random_user()
         CircleMember.objects.create(circle=self.circle, user=my_accomplice, is_admin=False)
 
-        another_user = self._get_random_user()
+        another_user = get_random_user()
         circle = Circle.objects.create(name='Test 2', status='Private', owner=another_user)
 
         payload = self._get_request_json(circle=circle.urlid, is_admin=True)
@@ -435,7 +429,7 @@ class PermissionsTestCase(APITestCase):
 
     def test_hack_post_circle_member_to_admin(self):
         self.setUpLoggedInUser()
-        another_user = self._get_random_user()
+        another_user = get_random_user()
         self.setUpCircle('Private', another_user)
 
         payload = self._get_request_json(circle=self.circle.urlid, user=self.user.urlid, is_admin=True)
@@ -445,7 +439,7 @@ class PermissionsTestCase(APITestCase):
 
     def test_hack_post_circle_member_again_to_admin(self):
         self.setUpLoggedInUser()
-        another_user = self._get_random_user()
+        another_user = get_random_user()
         self.setUpCircle('Private', another_user)
 
         CircleMember.objects.create(user=self.user, circle=self.circle, is_admin=False)
